package
Version:
v0.0.0-...-9b3c99f
Opens a new window with list of versions in this module.
Published: Jun 27, 2019
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Directory struct {
File
Children []interface{} `json:"children"`
}
Directory extends File and contains a splice of files and/or directorie as Children
type File struct {
Name string `json:"name"`
Type string `json:"type"`
Size int64 `json:"size"`
}
File represents a unix file
Source Files
¶
Click to show internal directories.
Click to hide internal directories.